## Installation		

### Source Code
- Download [Version 2.4](https://github.com/sepandhaghighi/art/archive/v2.4.zip) or [Latest Source ](https://github.com/sepandhaghighi/art/archive/dev.zip)
- `python3 setup.py install --upgrade` or `python setup.py install --upgrade` (Need root access)				

### PyPI


- Check [Python Packaging User Guide](https://packaging.python.org/installing/)     
- `pip install art==2.4` or `pip3 install art==2.4` (Need root access)

### Easy Install

- Run `easy_install "art==2.4"` (Need root access)
